package com.ruoyi.system.service;


import com.ruoyi.system.domain.SysDeptJl;

import java.util.List;

/**
 * 吉林地区管理Service接口
 *
 * @author CH
 * @date 2022-03-25
 */
public interface ISysDeptJlService
{
    /**
     * 查询吉林地区管理
     *
     * @param id 吉林地区管理主键
     * @return 吉林地区管理
     */
    public SysDeptJl selectSysDeptJlById(String id);

    /**
     * 查询吉林地区管理列表
     *
     * @param sysDeptJl 吉林地区管理
     * @return 吉林地区管理集合
     */
    public List<SysDeptJl> selectSysDeptJlList(SysDeptJl sysDeptJl);

    /**
     * 检查是否有父级行政地区id信息
     *
     * @param parentId 父级行政地区uuid
     */
    public void checkParentId(String parentId);

    /**
     * 检查是否有子级行政地区信息
     *
     * @param id uuid
     */
    public void checkChildrenLevel(String id);

    /**
     * 新增吉林地区管理
     *
     * @param sysDeptJl 吉林地区管理
     * @return 结果
     */
    public int insertSysDeptJl(SysDeptJl sysDeptJl);

    /**
     * 修改吉林地区管理
     *
     * @param sysDeptJl 吉林地区管理
     * @return 结果
     */
    public int updateSysDeptJl(SysDeptJl sysDeptJl);

    /**
     * 批量删除吉林地区管理
     *
     * @param ids 需要删除的吉林地区管理主键集合
     * @return 结果
     */
    public int deleteSysDeptJlByIds(String[] ids);

    /**
     * 删除吉林地区管理信息
     *
     * @param id 吉林地区管理主键
     * @return 结果
     */
    public int deleteSysDeptJlById(String id);

    /**
     * 同步行政区到部门表
     * @return 结果
     */
    public boolean syncToDept();
}
